==> vacuum-1.1.0.tar.xz: vacuum-1.1.0/src/translations/ru/messagewidgets.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru" sourcelanguage="en">
<context>
    <name>EditWidgetClass</name>
    <message>
        <source>Send</source>
        <translation>Отправить</translation>
    </message>
</context>
<context>
    <name>MessageWidgets</name>
    <message>
        <source>Messages</source>
        <translation>Сообщения</translation>
    </message>
    <message>
        <source>Tab Window %1</source>
        <translation>Окно  со вкладками %1</translation>
    </message>
    <message>
        <source>Main Tab Window</source>
        <translation>Основное окно</translation>
    </message>
    <message>
        <source>Message Widgets Manager</source>
        <translation>Диспетчер виджетов сообщений</translation>
    </message>
    <message>
        <source>Allows other modules to use standard widgets for messaging</source>
        <translation>Позволяет другим модулям использовать стандартные виджеты для обмена сообщениями</translation>
    </message>
    <message>
        <source>Quote selected text</source>
        <translation>Цитировать выделенный текст</translation>
    </message>
    <message>
        <source>Tab Window</source>
        <translation>Окно  со вкладками</translation>
    </message>
    <message>
        <source>Enable tab windows</source>
        <translation>Использовать окна со вкладками</translation>
    </message>
    <message>
        <source>Show status changes in chat windows</source>
        <translation>Показывать изменения статуса в окне чата</translation>
    </message>
    <message>
        <source>Auto resize input field</source>
        <translation>Автоматически изменять размер поля ввода</translation>
    </message>
    <message>
        <source>Show contact information in chat windows</source>
        <translation>Показывать информацию о контакте в окне чата</translation>
    </message>
    <message>
        <source>Save status messages to history</source>
        <translation>Сохранять статусные сообщения в истории</translation>
    </message>
    <message>
        <source>Tab window</source>
        <translation>Окно со вкладками</translation>
    </message>
    <message>
        <source>Close tab</source>
        <translation>Закрыть вкладку</translation>
    </message>
    <message>
        <source>Detach tab to separate window</source>
        <translation>Отцепить вкладку в отдельное окно</translation>
    </message>
    <message>
        <source>Next tab</source>
        <translation>Следующая вкладка</translation>
    </message>
    <message>
        <source>Previous tab</source>
        <translation>Предыдущая вкладка</translation>
    </message>
    <message>
        <source>Set tabs closable</source>
        <translation>Сделать вкладки закрываемыми</translation>
    </message>
    <message>
        <source>Show tabs at bottom</source>
        <translation>Показывать вкладки внизу</translation>
    </message>
    <message>
        <source>Rename tab window</source>
        <translation>Переименовать окно со вкладками</translation>
    </message>
    <message>
        <source>Delete tab window</source>
        <translation>Удалить окно со вкладками</translation>
    </message>
    <message>
        <source>Use as default tab window</source>
        <translation>Использовать как основное окно со вкладками</translation>
    </message>
    <message>
        <source>Alt+%1</source>
        <comment>Show tab</comment>
        <translation>Alt+%1</translation>
    </message>
    <message>
        <source>Message windows</source>
        <translation>Окна сообщений</translation>
    </message>
    <message>
        <source>Chat window</source>
        <translation>Окно чата</translation>
    </message>
    <message>
        <source>Send message</source>
        <translation>Отправить сообщение</translation>
    </message>
    <message>
        <source>Return</source>
        <comment>Send message</comment>
        <translation>Return</translation>
    </message>
    <message>
        <source>Message window</source>
        <translation>Окно сообщения</translation>
    </message>
    <message>
        <source>Ctrl+Return</source>
        <comment>Send message</comment>
        <translation>Ctrl+Return</translation>
    </message>
    <message>
        <source>Edit next message</source>
        <translation>Редактировать последующее сообщение</translation>
    </message>
    <message>
        <source>Ctrl+Down</source>
        <comment>Edit next message</comment>
        <translation>Ctrl+Down</translation>
    </message>
    <message>
        <source>Edit previous message</source>
        <translation>Редактировать предыдущее сообщение</translation>
    </message>
    <message>
        <source>Ctrl+Up</source>
        <comment>Edit previous message</comment>
        <translation>Ctrl+Up</translation>
    </message>
    <message>
        <source>Ctrl+W</source>
        <comment>Close tab</comment>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <source>Show tabs indices</source>
        <translation>Показывать номера вкладок</translation>
    </message>
    <message>
        <source>Close tab window</source>
        <translation>Закрыть окно со вкладками</translation>
    </message>
    <message>
        <source>Esc</source>
        <comment>Close tab window</comment>
        <translation>Esc</translation>
    </message>
    <message>
        <source>Close message window</source>
        <translation>Закрыть окно сообщений</translation>
    </message>
    <message>
        <source>Esc</source>
        <comment>Close message window</comment>
        <translation>Esc</translation>
    </message>
</context>
<context>
    <name>MessageWindow</name>
    <message>
        <source>Next - %1</source>
        <translation>Следующий - %1</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
</context>
<context>
    <name>MessageWindowClass</name>
    <message>
        <source>Message</source>
        <translation>Сообщение</translation>
    </message>
    <message>
        <source>To:</source>
        <translation>Кому:</translation>
    </message>
    <message>
        <source>Subject:</source>
        <translation>Тема:</translation>
    </message>
    <message>
        <source>Reply</source>
        <translation>Ответить</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Переслать</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Чат</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Отправить</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Следующее</translation>
    </message>
</context>
<context>
    <name>MessengerOptionsClass</name>
    <message>
        <source>Minimum input field lines:</source>
        <translation>Минимальное число строк в поле ввода:</translation>
    </message>
    <message>
        <source>Clean chat windows after closing in </source>
        <translation>Очищать окна чата после закрытия через</translation>
    </message>
    <message>
        <source> minutes</source>
        <translation> минут</translation>
    </message>
    <message>
        <source>(0 - do not clean)</source>
        <translation>(0 - не очищать)</translation>
    </message>
</context>
<context>
    <name>ReceiversWidget</name>
    <message>
        <source>Receivers</source>
        <translation>Получатели</translation>
    </message>
    <message>
        <source>Not in Roster</source>
        <translation>Не в контакт-листе</translation>
    </message>
    <message>
        <source>Contact</source>
        <translation>Контакт</translation>
    </message>
    <message>
        <source>Jid</source>
        <translation>JID</translation>
    </message>
    <message>
        <source>Agents</source>
        <translation>Агенты</translation>
    </message>
    <message>
        <source>Blank group</source>
        <translation>Общая группа</translation>
    </message>
    <message>
        <source>My Resources</source>
        <translation>Мои ресурсы</translation>
    </message>
    <message>
        <source>Add receiver</source>
        <translation>Добавить получателя</translation>
    </message>
    <message>
        <source>Enter valid contact jid:</source>
        <translation>Введите корректный JID:</translation>
    </message>
</context>
<context>
    <name>ReceiversWidgetClass</name>
    <message>
        <source>Add</source>
        <translation>Добавить</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Обновить</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Все</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Никого</translation>
    </message>
</context>
<context>
    <name>TabWindow</name>
    <message>
        <source>Close Tab</source>
        <translation>Закрыть вкладку</translation>
    </message>
    <message>
        <source>Next Tab</source>
        <translation>След. вкладка</translation>
    </message>
    <message>
        <source>Prev. Tab</source>
        <translation>Пред. вкладка</translation>
    </message>
    <message>
        <source>Tabs Closable</source>
        <translation>Закрываемые вкладки</translation>
    </message>
    <message>
        <source>Detach to Separate Window</source>
        <translation>Отцепить в отдельное окно</translation>
    </message>
    <message>
        <source>Join to</source>
        <translation>Присоединить к</translation>
    </message>
    <message>
        <source>New Tab Window</source>
        <translation>Новое окно со вкладками</translation>
    </message>
    <message>
        <source>Use as Default Tab Window</source>
        <translation>Использовать как окно по умолчанию</translation>
    </message>
    <message>
        <source>Rename Tab Window</source>
        <translation>Переименовать окно</translation>
    </message>
    <message>
        <source>Delete Tab Window</source>
        <translation>Удалить окно</translation>
    </message>
    <message>
        <source>Tab window name:</source>
        <translation>Наименование окна:</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this tab window?</source>
        <translation>Вы уверены что хотите удалить это окно со вкладками?</translation>
    </message>
    <message>
        <source>Show Tabs at Bottom of the Window</source>
        <translation>Показывать вкладки внизу окна</translation>
    </message>
    <message>
        <source>Show Tabs Indices</source>
        <translation>Показывать номера вкладок</translation>
    </message>
    <message>
        <source>Close Tab Window</source>
        <translation>Закрыть окно</translation>
    </message>
    <message>
        <source>%1) %2</source>
        <comment>First is tab index, second is tab name</comment>
        <translation>%1) %2</translation>
    </message>
    <message>
        <source>Remove all tabs on window close</source>
        <translation>Закрывать все вкладки при закрытии окна</translation>
    </message>
</context>
<context>
    <name>TabWindowClass</name>
    <message>
        <source>Tab 1</source>
        <translation>Tab 1</translation>
    </message>
</context>
</TS>

==> vacuum-1.1.2_1798.tar.xz: vacuum-1.1.2_1798/src/translations/ru/messagewidgets.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru" sourcelanguage="en">
<context>
    <name>ChatWindow</name>
    <message>
        <source>Quote selected text</source>
        <translation>Цитировать выделенный текст</translation>
    </message>
</context>
<context>
    <name>EditWidget</name>
    <message>
        <source>Send</source>
        <translation>Отправить</translation>
    </message>
</context>
<context>
    <name>MessageWidgets</name>
    <message>
        <source>Messages</source>
        <translation>Сообщения</translation>
    </message>
    <message>
        <source>Tab Window %1</source>
        <translation>Окно  со вкладками %1</translation>
    </message>
    <message>
        <source>Main Tab Window</source>
        <translation>Основное окно</translation>
    </message>
    <message>
        <source>Message Widgets Manager</source>
        <translation>Диспетчер виджетов сообщений</translation>
    </message>
    <message>
        <source>Allows other modules to use standard widgets for messaging</source>
        <translation>Позволяет другим модулям использовать стандартные виджеты для обмена сообщениями</translation>
    </message>
    <message>
        <source>Quote selected text</source>
        <translation>Цитировать выделенный текст</translation>
    </message>
    <message>
        <source>Tab Window</source>
        <translation>Окно  со вкладками</translation>
    </message>
    <message>
        <source>Enable tab windows</source>
        <translation>Использовать окна со вкладками</translation>
    </message>
    <message>
        <source>Show status changes in chat windows</source>
        <translation>Показывать изменения статуса в окне чата</translation>
    </message>
    <message>
        <source>Auto resize input field</source>
        <translation>Автоматически изменять размер поля ввода</translation>
    </message>
    <message>
        <source>Show contact information in chat windows</source>
        <translation>Показывать информацию о контакте в окне чата</translation>
    </message>
    <message>
        <source>Save status messages to history</source>
        <translation>Сохранять статусные сообщения в истории</translation>
    </message>
    <message>
        <source>Tab window</source>
        <translation>Окно со вкладками</translation>
    </message>
    <message>
        <source>Close tab</source>
        <translation>Закрыть вкладку</translation>
    </message>
    <message>
        <source>Detach tab to separate window</source>
        <translation>Отцепить вкладку в отдельное окно</translation>
    </message>
    <message>
        <source>Next tab</source>
        <translation>Следующая вкладка</translation>
    </message>
    <message>
        <source>Previous tab</source>
        <translation>Предыдущая вкладка</translation>
    </message>
    <message>
        <source>Set tabs closable</source>
        <translation>Сделать вкладки закрываемыми</translation>
    </message>
    <message>
        <source>Show tabs at bottom</source>
        <translation>Показывать вкладки внизу</translation>
    </message>
    <message>
        <source>Rename tab window</source>
        <translation>Переименовать окно со вкладками</translation>
    </message>
    <message>
        <source>Delete tab window</source>
        <translation>Удалить окно со вкладками</translation>
    </message>
    <message>
        <source>Use as default tab window</source>
        <translation>Использовать как основное окно со вкладками</translation>
    </message>
    <message>
        <source>Alt+%1</source>
        <comment>Show tab</comment>
        <translation>Alt+%1</translation>
    </message>
    <message>
        <source>Message windows</source>
        <translation>Окна сообщений</translation>
    </message>
    <message>
        <source>Chat window</source>
        <translation>Окно чата</translation>
    </message>
    <message>
        <source>Send message</source>
        <translation>Отправить сообщение</translation>
    </message>
    <message>
        <source>Return</source>
        <comment>Send message</comment>
        <translation>Return</translation>
    </message>
    <message>
        <source>Message window</source>
        <translation>Окно сообщения</translation>
    </message>
    <message>
        <source>Ctrl+Return</source>
        <comment>Send message</comment>
        <translation>Ctrl+Return</translation>
    </message>
    <message>
        <source>Edit next message</source>
        <translation>Редактировать последующее сообщение</translation>
    </message>
    <message>
        <source>Ctrl+Down</source>
        <comment>Edit next message</comment>
        <translation>Ctrl+Down</translation>
    </message>
    <message>
        <source>Edit previous message</source>
        <translation>Редактировать предыдущее сообщение</translation>
    </message>
    <message>
        <source>Ctrl+Up</source>
        <comment>Edit previous message</comment>
        <translation>Ctrl+Up</translation>
    </message>
    <message>
        <source>Ctrl+W</source>
        <comment>Close tab</comment>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <source>Show tabs indices</source>
        <translation>Показывать номера вкладок</translation>
    </message>
    <message>
        <source>Close tab window</source>
        <translation>Закрыть окно со вкладками</translation>
    </message>
    <message>
        <source>Esc</source>
        <comment>Close tab window</comment>
        <translation>Esc</translation>
    </message>
    <message>
        <source>Close message window</source>
        <translation>Закрыть окно сообщений</translation>
    </message>
    <message>
        <source>Esc</source>
        <comment>Close message window</comment>
        <translation>Esc</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Копировать</translation>
    </message>
    <message>
        <source>Send mail</source>
        <translation>Отправить письмо</translation>
    </message>
    <message>
        <source>Open link</source>
        <translation>Открыть ссылку</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Копировать адрес</translation>
    </message>
    <message>
        <source>Search on Google &apos;%1&apos;</source>
        <translation>Искать в Google &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Close other tabs</source>
        <translation>Закрыть другие вкладки</translation>
    </message>
    <message>
        <source>Ctrl+Shift+W</source>
        <comment>Close other tabs</comment>
        <translation>Ctrl+Shift+W</translation>
    </message>
</context>
<context>
    <name>MessageWindow</name>
    <message>
        <source>Next - %1</source>
        <translation>Следующее - %1</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
</context>
<context>
    <name>MessageWindowClass</name>
    <message>
        <source>Message</source>
        <translation>Сообщение</translation>
    </message>
    <message>
        <source>To:</source>
        <translation>Кому:</translation>
    </message>
    <message>
        <source>Subject:</source>
        <translation>Тема:</translation>
    </message>
    <message>
        <source>Reply</source>
        <translation>Ответить</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Переслать</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Чат</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Отправить</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Следующее</translation>
    </message>
</context>
<context>
    <name>MessengerOptionsClass</name>
    <message>
        <source>Minimum input field lines:</source>
        <translation>Минимальное число строк в поле ввода:</translation>
    </message>
    <message>
        <source>Clean chat windows after closing in </source>
        <translation>Очищать окна чата после закрытия через</translation>
    </message>
    <message>
        <source> minutes</source>
        <translation> минут</translation>
    </message>
    <message>
        <source>(0 - do not clean)</source>
        <translation>(0 - не очищать)</translation>
    </message>
</context>
<context>
    <name>ReceiversWidget</name>
    <message>
        <source>Receivers</source>
        <translation>Получатели</translation>
    </message>
    <message>
        <source>Not in Roster</source>
        <translation>Не в контакт-листе</translation>
    </message>
    <message>
        <source>Contact</source>
        <translation>Контакт</translation>
    </message>
    <message>
        <source>Jid</source>
        <translation>JID</translation>
    </message>
    <message>
        <source>Agents</source>
        <translation>Агенты</translation>
    </message>
    <message>
        <source>My Resources</source>
        <translation>Мои ресурсы</translation>
    </message>
    <message>
        <source>Add receiver</source>
        <translation>Добавить получателя</translation>
    </message>
    <message>
        <source>Enter valid contact jid:</source>
        <translation>Введите корректный JID:</translation>
    </message>
    <message>
        <source>Without Groups</source>
        <translation>Без групп</translation>
    </message>
</context>
<context>
    <name>ReceiversWidgetClass</name>
    <message>
        <source>Add</source>
        <translation>Добавить</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Обновить</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Все</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Никого</translation>
    </message>
    <message>
        <source>All Online</source>
        <translation>Все в сети</translation>
    </message>
</context>
<context>
    <name>TabWindow</name>
    <message>
        <source>Close Tab</source>
        <translation>Закрыть вкладку</translation>
    </message>
    <message>
        <source>Next Tab</source>
        <translation>След. вкладка</translation>
    </message>
    <message>
        <source>Prev. Tab</source>
        <translation>Пред. вкладка</translation>
    </message>
    <message>
        <source>Tabs Closable</source>
        <translation>Закрываемые вкладки</translation>
    </message>
    <message>
        <source>Detach to Separate Window</source>
        <translation>Отцепить в отдельное окно</translation>
    </message>
    <message>
        <source>Join to</source>
        <translation>Присоединить к</translation>
    </message>
    <message>
        <source>New Tab Window</source>
        <translation>Новое окно со вкладками</translation>
    </message>
    <message>
        <source>Use as Default Tab Window</source>
        <translation>Использовать как окно по умолчанию</translation>
    </message>
    <message>
        <source>Rename Tab Window</source>
        <translation>Переименовать окно</translation>
    </message>
    <message>
        <source>Delete Tab Window</source>
        <translation>Удалить окно</translation>
    </message>
    <message>
        <source>Tab window name:</source>
        <translation>Наименование окна:</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this tab window?</source>
        <translation>Вы уверены что хотите удалить это окно со вкладками?</translation>
    </message>
    <message>
        <source>Show Tabs at Bottom of the Window</source>
        <translation>Показывать вкладки внизу окна</translation>
    </message>
    <message>
        <source>Show Tabs Indices</source>
        <translation>Показывать номера вкладок</translation>
    </message>
    <message>
        <source>Close Tab Window</source>
        <translation>Закрыть окно со вкладками</translation>
    </message>
    <message>
        <source>Remove all tabs on window close</source>
        <translation>Закрывать все вкладки при закрытии окна</translation>
    </message>
    <message>
        <source>%1) %2</source>
        <translation>%1) %2</translation>
    </message>
    <message>
        <source>Close Other Tabs</source>
        <translation>Закрыть другие вкладки</translation>
    </message>
</context>
<context>
    <name>TabWindowClass</name>
    <message>
        <source>Tab 1</source>
        <translation>Tab 1</translation>
    </message>
</context>
</TS>
